package com.huimv.video.service.impl;

import com.huimv.video.domain.MobileUser;
import com.huimv.video.repo.MobileUserRepository;
import com.huimv.video.result.Result;
import com.huimv.video.result.ResultStatus;
import com.huimv.video.service.MobileUserService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.util.DigestUtils;

import java.util.List;

@Service
public class MobileUserServiceImpl implements MobileUserService {

	@Autowired
	private MobileUserRepository rep;

	@Override
	public Result add(MobileUser entity){
		if (entity == null){
			return new Result(10002, ResultStatus.addNull);
		}
		try {
			String password = entity.getPassword();
			entity.setPassword(DigestUtils.md5DigestAsHex(password.getBytes()));
			rep.save(entity);
			return new Result(10000,"注册成功，即将跳转到登录页面");
		}catch (Exception e){
			return new Result(10001,"注册失败");
		}
	}

	@Override
	public Result remove(Integer[] ids) {
		if (ids == null || ids.length==0){
			return new Result(10002,ResultStatus.deleteNull);
		}
		try {
			for (Integer id : ids) {
				rep.deleteById(id);
			}
			return new Result(10000,ResultStatus.deleteSuccess);
		}catch (Exception e){
			return new Result(10001,ResultStatus.deleteFailed);
		}
	}

	@Override
	public Result update(MobileUser entity) {
		if (entity == null){
			return new Result(10002,ResultStatus.updateNull);
		}
		try {
			rep.save(entity);
			return new Result(10000,ResultStatus.updateSuccess);
		}catch (Exception e){
			return new Result(10001,ResultStatus.updateFailed);
		}
	}

	@Override
	public Result findAll() {
		try {
			List<MobileUser> all = rep.findAll();
			return new Result(10000,ResultStatus.findSuccess,all);
		}catch (Exception e){
			return new Result(10001,ResultStatus.findFailed,null);
		}
	}

	@Override
	public Result findAllById(Integer id) {
		try {
			MobileUser entity = rep.findById(id).get();
			return new Result(10000,ResultStatus.findSuccess,entity);
		}catch (Exception e){
			return new Result(10001,ResultStatus.findFailed,null);
		}
	}

	@Override
	public Result login(String account, String password) {
		password = DigestUtils.md5DigestAsHex(password.getBytes());
		MobileUser byUserNameAndPassword = rep.findByAccountAndPassword(account, password);
		if (byUserNameAndPassword == null){
			return new Result(10001,"登录失败",null);
		}
		return new Result(10000,"登录成功",byUserNameAndPassword);
	}

	@Override
	public Result updateIndex(Integer id, Integer userId) {
		MobileUser mobileUser = rep.findById(userId).get();
		mobileUser.setIndexVideo(id);
		rep.save(mobileUser);
		return new Result(10000,"设置成功");
	}

	@Override
	public Integer findIndex(Integer userId) {

		return rep.findById(userId).get().getIndexVideo();
	}

}
